@@ -1,6 +1,6 @@
 ;;; devbook-mode.el --- edit the Gentoo Devmanual  -*-lexical-binding:t-*-
 
-;; Copyright 2020-2025 Gentoo Authors
+;; Copyright 2020-2026 Gentoo Authors
 
 ;; Author: Ulrich Müller <ulm@gentoo.org>
 ;; Maintainer: <emacs@gentoo.org>
@@ -100,7 +100,7 @@ between the element name and its first attribute."
 				     buffer-file-name))
 		  (match-string 1 buffer-file-name)
 		(skeleton-read "Path: "))))
-    (if (string-match "\\`/*\\'" path)
+    (if (string-match-p "\\`/*\\'" path)
 	"root=\"true\""
       (concat "self=\"" (file-name-as-directory path) "\"")))
   ">\n"
