@@ -1,13 +1,13 @@
 ;;; ebuild-mode.el --- edit ebuild and eclass files  -*-lexical-binding:t-*-
 
-;; Copyright 2006-2025 Gentoo Authors
+;; Copyright 2006-2026 Gentoo Authors
 
 ;; Author: Matthew Kennedy <mkennedy@gentoo.org>
 ;;	Diego Pettenò <flameeyes@gentoo.org>
 ;;	Christian Faulhammer <fauli@gentoo.org>
 ;;	Ulrich Müller <ulm@gentoo.org>
 ;; Maintainer: <emacs@gentoo.org>
-;; Version: 1.79
+;; Version: 1.81
 ;; Keywords: languages, processes
 
 ;; This file is free software: you can redistribute it and/or modify
@@ -72,7 +72,7 @@
   :group 'ebuild)
 
 (defcustom ebuild-mode-eapi-list
-  '("7" "8")
+  '("7" "8" "9")
   "List of supported EAPIs.
 The most recent EAPI is listed last."
   :type '(repeat string)
@@ -525,9 +525,9 @@ an explanation of arguments S, PREDICATE and MODE."
 		(mapcar (lambda (x) (concat x " "))
 			(cond ((not (stringp s1))
 			       '("pkgdev" "pkgcheck"))
-			      ((string-match "\\<pkgdev\\s-+$" s1)
+			      ((string-match-p "\\<pkgdev\\s-+$" s1)
 			       ebuild-mode-pkgdev-commands)
-			      ((string-match "\\<pkgcheck\\s-+$" s1)
+			      ((string-match-p "\\<pkgcheck\\s-+$" s1)
 			       ebuild-mode-pkgcheck-commands)
 			      (t (list s2))))
 		predicate)))
@@ -574,11 +574,11 @@ Like `compile', but with autocompletion for pkgcheck."
 	 (basename (file-name-nondirectory buffer-file-name))
 	 (pf (file-name-sans-extension basename)))
     ;; sanity check
-    (unless (string-match "\\.ebuild\\'" (file-name-sans-versions basename))
+    (unless (string-match-p "\\.ebuild\\'" (file-name-sans-versions basename))
       (error "Filename \"%s\" does not end in \".ebuild\"" basename))
     (unless (and (file-exists-p
 		  (expand-file-name "../profiles/repo_name" catdir))
-		 (string-match (concat "\\`" (regexp-quote pn) "-") pf))
+		 (string-match-p (concat "\\`" (regexp-quote pn) "-") pf))
       (error "This does not look like an ebuild repository"))
     (let ((builddir (expand-file-name (concat category "/" pf)
 				      ebuild-mode-portage-tmpdir)))
@@ -669,8 +669,7 @@ With prefix argument OTHER-WINDOW, visit the directory in another window."
     (let* ((workdir (expand-file-name "work" builddir))
 	   (wd (file-name-as-directory workdir))
 	   (sd (file-name-as-directory s)))
-      (unless (and (>= (length sd) (length wd))
-		   (string-equal (substring sd 0 (length wd)) wd))
+      (unless (eq t (compare-strings sd 0 (length wd) wd 0 nil))
 	(error "S=\"%s\" is outside WORKDIR=\"%s\"" s workdir)))
     (if other-window
 	(find-file-other-window s)
@@ -686,13 +685,19 @@ With prefix argument OTHER-WINDOW, visit the directory in another window."
       (error "Cannot read file \"%s\"" file))
     (if other-window
 	(find-file-other-window file)
-      (find-file file))
-    ;; decode ANSI SGR control sequences if possible (tty-format.el)
-    (and (assq 'ansi-colors format-alist)
-	 (save-excursion
-	   (goto-char (point-min))
-	   (re-search-forward "\e\\[[0-9;]*m" nil t))
-	 (format-decode-buffer 'ansi-colors))))
+      (find-file file))))
+
+(defun ebuild-mode-decode-ansi-colors ()
+  "Decode ANSI SGR control sequences in build.log.
+If available, uses the \"tty-format\" package to translate the buffer
+from the `ansi-colors' file format."
+  (and buffer-file-name
+       (string-match-p "/build\\>.*\\.log\\'" buffer-file-name)
+       (assq 'ansi-colors format-alist)
+       (save-excursion
+         (goto-char (point-min))
+	 (re-search-forward "\e\\[[0-9;]*m" nil t))
+       (format-decode-buffer 'ansi-colors)))
 
 ;;; Modify package keywords.
 ;; This is basically a reimplementation of "ekeyword" in Emacs Lisp.
@@ -994,7 +999,6 @@ See `bug-reference-url-format' for further details.")
     (unless (local-variable-p 'indent-tabs-mode (current-buffer))
       (setq indent-tabs-mode ebuild-mode-xml-indent-tabs)))))
 
-;;;###autoload
 (defun ebuild-repo-mode-maybe-enable ()
   "Enable `ebuild-repo-mode' when the file is in an ebuild repository."
   ;; We assume that we are in an ebuild repository if we find a file
@@ -1002,7 +1006,7 @@ See `bug-reference-url-format' for further details.")
   (and buffer-file-name
        (locate-dominating-file buffer-file-name "profiles/repo_name")
        ;; Don't enable the mode for patches
-       (not (string-match "\\.\\(diff\\|patch\\)\\'" buffer-file-name))
+       (not (string-match-p "\\.\\(diff\\|patch\\)\\'" buffer-file-name))
        (not (derived-mode-p 'diff-mode))
        (ebuild-repo-mode 1)))
 
@@ -1015,7 +1019,7 @@ in a Gentoo profile."
   (beginning-of-line)
   (insert (concat comment-start
 		  (and (/= 0 (length comment-start))
-		       (not (string-match "[ \t]" comment-start -1))
+		       (not (string-match-p "[ \t]" comment-start -1))
 		       " "))
 	  (format "%s <%s> (%s)\n"
 		  ebuild-mode-full-name ebuild-mode-mail-address
@@ -1104,11 +1108,19 @@ in a Gentoo profile."
 ;;;###autoload
 (add-to-list 'auto-mode-alist '("\\.eclass\\'" . ebuild-eclass-mode))
 
+;;;###autoload
+(defun ebuild-mode-find-file-hook ()
+  "Hook function to be called from `find-file-hook' (or `find-file-hooks').
+Enable `ebuild-repo-mode' when the file is in an ebuild repository.
+Decode ANSI SGR control sequences in build.log if possible."
+  (ebuild-repo-mode-maybe-enable)
+  (ebuild-mode-decode-ansi-colors))
+
 ;;;###autoload
 (add-hook
  ;; XEmacs 21.5 doesn't have find-file-hook
  (if (boundp 'find-file-hook) 'find-file-hook 'find-file-hooks)
- #'ebuild-repo-mode-maybe-enable)
+ #'ebuild-mode-find-file-hook)
 
 (provide 'ebuild-mode)
 
