@@ -1,6 +1,6 @@
 ;;; ebuild-mode-tests.el --- tests for ebuild-mode.el  -*-lexical-binding:t-*-
 
-;; Copyright 2024-2025 Gentoo Authors
+;; Copyright 2024-2026 Gentoo Authors
 
 ;; Author: Ulrich Müller <ulm@gentoo.org>
 ;; Maintainer: <emacs@gentoo.org>
@@ -22,6 +22,8 @@
 
 (require 'ert)
 (require 'ebuild-mode)
+(require 'ebuild-mode-keywords)
+(require 'ebuild-mode-kw-gen)
 
 (eval-when-compile
   (unless (fboundp 'cl-letf)
@@ -66,12 +68,30 @@
     ;; was it non-destructive?
     (should (equal alist alist1))))
 
+(ert-deftest ebuild-mode-test-duplicate-keywords ()
+  (let* ((keywords
+	  (list ebuild-mode-keywords-EAPI
+		ebuild-mode-keywords-0
+		ebuild-mode-keywords-functions
+		ebuild-mode-keywords-sandbox
+		ebuild-mode-keywords-eapi-deprecated
+		ebuild-mode-keywords-warn
+		ebuild-mode-keywords-eclassdoc
+		ebuild-mode-keywords-eclassdoc-warn
+		;; ebuild-mode-keywords-eclass can contain duplicates
+		(cons (delete-dups
+		       (copy-sequence (car ebuild-mode-keywords-eclass)))
+		      (cdr ebuild-mode-keywords-eclass))))
+	 (names (apply #'append (mapcar #'car keywords))))
+    (should (equal names
+		   (delete-dups (copy-sequence names))))))
+
 (ert-deftest ebuild-mode-test-font-lock-keywords ()
   (let ((case-fold-search nil)
 	(findkey (lambda (key)
 		   (catch 'found
 		     (dolist (c ebuild-mode-font-lock-keywords)
-		       (if (string-match (car c) key)
+		       (if (string-match-p (car c) key)
 			   (throw 'found (cdr c))))))))
     ;; Verify that all regexps are below the 32 KiB limit.
     ;; Our regexps are ASCII only, so don't bother with string-bytes
@@ -190,6 +210,21 @@
 	     (ebuild-mode-find-s)
 	     "/tmp/portage/app-misc/foo-1/work/foo ä→$\\'`bar"))))
 
+(ert-deftest ebuild-mode-test-decode-ansi-colors ()
+  (skip-unless (require 'tty-format nil t))
+  (with-temp-buffer
+    (insert "\e[32m * \e[39;49;00mfoo\n")
+    (let ((buffer-file-name "/home/larry/build.log"))
+      (ebuild-mode-decode-ansi-colors))
+    (should (equal (buffer-string) " * foo\n"))
+    (goto-char (point-min))
+    (search-forward "*")
+    ;; just test for any face property, because ansi-color has changed
+    ;; between Emacs versions
+    (should (get-text-property (match-beginning 0) 'face))
+    (search-forward "foo")
+    (should-not (get-text-property (match-beginning 0) 'face))))
+
 (ert-deftest ebuild-mode-test-get-keywords ()
   (with-temp-buffer
     (insert "KEYWORDS=\"amd64 arm ~ppc64 x86\"\n")
@@ -331,6 +366,39 @@
     (should (equal (local-key-binding "\C-c\C-eu")
 		   'ebuild-run-command-unpack))))
 
+(ert-deftest ebuild-mode-test-keyword-generation ()
+  (cl-letf (((symbol-function 'directory-files)
+	     (lambda (&rest _args)
+	       '("spam.eclass" "sausage.eclass" "eggs.eclass")))
+	    ((symbol-function 'insert-file-contents)
+	     (lambda (file &rest _args)
+	       (let ((name (file-name-sans-extension
+			    (file-name-nondirectory file))))
+		 (if (string-equal name "spam")
+		     (insert "# @DEAD\n\n"))
+		 (insert
+		  "# @FUNCTION: " name "_bacon\n"
+		  name "_bacon() { spam; }\n\n"
+		  "# @FUNCTION: " name "_tomato\n"
+		  name "_tomato ()\n"
+		  "{ spam; }\n\n"
+		  "# @FUNCTION: " name "_spam\n"
+		  "function " name "_spam { spam; }\n\n"
+		  "# @FUNCTION: " name "_baked_beans\n"
+		  "# @INTERNAL\n"
+		  name "_baked_beans() { spam; }\n\n"
+		  "# @FUNCTION: " name "_undefined\n\n"
+		  name "_undocumented() { spam; }\n"))
+	       (goto-char (point-min)))))
+    (should (equal
+	     (ebuild-mode-test-run-silently
+	      (emkg-get-all-eclass-keywords "\t  " 50))
+	     (concat "\t  ;; eggs\n"
+		     "\t  \"eggs_bacon\" \"eggs_tomato\" \"eggs_spam\"\n"
+		     "\t  ;; sausage\n"
+		     "\t  \"sausage_bacon\" \"sausage_tomato\"\n"
+		     "\t  \"sausage_spam\"\n")))))
+
 (provide 'ebuild-mode-tests)
 
 ;; Local Variables:
